==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core/lumina-open/i18n/lumina-open_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Öffnen mit…</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Bevorzugt</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Ort der Binärdatei</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Finden</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Diese Anwendung als Standardanwendung verwenden </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(E-Mail-Verknüpfung)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(Webadresse - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Entwicklung</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Ausbildung</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Büro</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Wissenschaft</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Dienstprogramme</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Andere</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="274"/>
        <source>Find Application Binary</source>
        <translation>Ausführbare Anwendung finden</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>File Error</source>
        <translation>Dateifehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="188"/>
        <location filename="../main.cpp" line="194"/>
        <source>Audio Volume %1%</source>
        <translation>Lautstärke %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="202"/>
        <location filename="../main.cpp" line="211"/>
        <source>Screen Brightness %1%</source>
        <translation>Bildschirmhelligkeit %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="243"/>
        <source>Invalid file or URL: %1</source>
        <translation>Ungültige Datei oder URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="264"/>
        <source>File could not be opened: %1</source>
        <translation>Datei konnte nicht geöffnet werden: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="273"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Fehlende Startup-Informationen für Programm-Verknüpfung (deformierte Verknüpfung): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="284"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>fehlende URL für URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="295"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>fehlender Pfad zum Verzeichnis der Verknüpfung: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="300"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>unbekannter Typ für Vernüpfung: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="362"/>
        <source>Binary Missing</source>
        <translation>Binärdatei fehlt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="362"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>Konnte &quot;%1&quot; nicht finden. Bitte stellen Sie zuerst sicher, dass es installiert ist.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="412"/>
        <source>Application Error</source>
        <translation>Anwendungsfehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="412"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>Bei folgender Anwendung ist ein Fehler aufgetreten und sie wurde beendet:</translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/core/lumina-open/i18n/lumina-open_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Öffnen mit…</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Bevorzugt</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Ort der Binärdatei</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Diese Anwendung als Standardanwendung verwenden </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(E-Mail-Verknüpfung)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(Webadresse - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Entwicklung</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Ausbildung</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Büro</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Wissenschaft</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Dienstprogramme</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Andere</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="274"/>
        <source>Find Application Binary</source>
        <translation>Ausführbare Anwendung finden</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>File Error</source>
        <translation>Dateifehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="188"/>
        <location filename="../main.cpp" line="194"/>
        <source>Audio Volume %1%</source>
        <translation>Lautstärke %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="202"/>
        <location filename="../main.cpp" line="211"/>
        <source>Screen Brightness %1%</source>
        <translation>Bildschirmhelligkeit %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="243"/>
        <source>Invalid file or URL: %1</source>
        <translation>Ungültige Datei oder URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="264"/>
        <source>Application entry is invalid: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="273"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Fehlende Startup-Informationen für Programm-Verknüpfung (deformierte Verknüpfung): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="284"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>fehlende URL für URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="295"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>fehlender Pfad zum Verzeichnis der Verknüpfung: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="300"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>unbekannter Typ für Vernüpfung: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="363"/>
        <source>Binary Missing</source>
        <translation>Binärdatei fehlt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="363"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>Konnte &quot;%1&quot; nicht finden. Bitte stellen Sie zuerst sicher, dass es installiert ist.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="413"/>
        <source>Application Error</source>
        <translation>Anwendungsfehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="413"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>Bei folgender Anwendung ist ein Fehler aufgetreten und sie wurde beendet:</translation>
    </message>
</context>
</TS>
